@@ -21,12 +21,12 @@ impl PathTracer {
     /// Add an path
     pub fn add(&self, path: Path, description: Description) {
         let data = PathEvent::AddPath { path, description };
-        self.tracer.send(data, None, None);
+        self.tracer.send(data, None);
     }
 
     /// Remove an path
     pub fn del(&self, path: Path) {
         let data = PathEvent::RemovePath { path };
-        self.tracer.send(data, None, None);
+        self.tracer.send(data, None);
     }
 }
